@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>
     SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
 
     SPDX-License-Identifier: LGPL-2.1-or-later
@@ -34,7 +34,7 @@ private:
     Akonadi::Collection collectionFromId(Akonadi::Collection::Id id) const;
     bool folderIsTrash(const Akonadi::Collection &col);
 
-    const QAbstractItemModel *mModel = nullptr;
+    const QAbstractItemModel *const mModel;
     Akonadi::Collection::Id the_trashCollectionFolder;
     Akonadi::Collection mFolder;
     int mNumberOfTrashToEmpty = 0;
