@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>
     SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
     SPDX-FileCopyrightText: 2012 Dan Vrátil <dvratil@redhat.com>
 
@@ -20,10 +20,7 @@ class Q_DECL_HIDDEN Akonadi::RemoveDuplicatesJob::Private
 {
 public:
     Private(RemoveDuplicatesJob *parent)
-        : mCurrentJob(nullptr)
-        , mJobCount(0)
-        , mKilled(false)
-        , mParent(parent)
+        :mParent(parent)
     {
     }
 
@@ -32,7 +29,7 @@ public:
         Akonadi::Collection collection = mFolders.value(mJobCount - 1);
         qCDebug(AKONADIMIME_LOG) << "Processing collection" << collection.name() << "(" << collection.id() << ")";
 
-        Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(collection, mParent);
+        auto *job = new Akonadi::ItemFetchJob(collection, mParent);
         job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
         job->fetchScope().fetchFullPayload();
         job->fetchScope().setIgnoreRetrievalErrors(true);
@@ -61,7 +58,7 @@ public:
 
         Q_EMIT mParent->description(mParent, i18n("Searching for duplicates..."));
 
-        Akonadi::ItemFetchJob *fjob = static_cast<Akonadi::ItemFetchJob *>(job);
+        auto *fjob = static_cast<Akonadi::ItemFetchJob *>(job);
         Akonadi::Item::List items = fjob->items();
 
         //find duplicate mails with the same messageid
@@ -119,7 +116,7 @@ public:
                 return;
             } else {
                 Q_EMIT mParent->description(mParent, i18n("Removing duplicates..."));
-                Akonadi::ItemDeleteJob *delCmd = new Akonadi::ItemDeleteJob(mDuplicateItems, mParent);
+                auto *delCmd = new Akonadi::ItemDeleteJob(mDuplicateItems, mParent);
                 mParent->connect(delCmd, &ItemDeleteJob::result, mParent, [this](KJob *job) {
                     slotDeleteDone(job);
                 });
@@ -139,11 +136,11 @@ public:
     Akonadi::Collection::List mFolders;
     Akonadi::Item::List mDuplicateItems;
     Akonadi::Job *mCurrentJob = nullptr;
-    int mJobCount;
+    int mJobCount = 0;
     bool mKilled = false;
 
 private:
-    RemoveDuplicatesJob *mParent = nullptr;
+    RemoveDuplicatesJob *const mParent;
 };
 
 using namespace Akonadi;
